#Purpose: Replication file for Paper "Zum Einfluss der Parteinähe auf das Abstimmungsverhalten der Bundesverfassungsrichter – 
#eine quantitative Untersuchung"; The file creates the Community Plot Figure 1 and robustness checks for it
#Author: Sebastian Sternberg
#Date: 08.05.2017
#Input files:adj_matrix_landau_weighted.csv; adj_matrix_landau_weighted_reduced.csv
#Output files:communityplot_landau1.pdf, communityplot_landau2.pdf, plus two robustness graphs:
# communityplot_landau1_reduced.pdf, communityplot_landau2_reduced.pdf


#Empty environment and load required packages
rm(list = ls())

#if extrafont and font_import is not already installed, 
#install it before to be able to recreate the graphs! 

packages <- c("igraph", "statnet", "RSiena", "extrafont", "showtext")
for (p in packages) {
  if (p %in% installed.packages()[,1]) require(p, character.only=T)
  else {
    install.packages(p)
    library(p, character.only=T)
  }
}

# Once you have installed it on your computer, do not run it again. It takes forever. This is why it is
#outcommented here

# font_import()
# loadfonts(device = "win")

#set an appropriate working directory where the file named adj_matrix_landau_weighted.csv is located


#############################################################################
#Here starts the production of the community network plots#####################
##############################################################################

# load the weighted matrix and create a subset for the time period of 2005-2011
df <- read.csv2("adj_matrix_landau_weighted.csv", stringsAsFactors = F)

df_05 <- df[2:9,3:10] #make a subset from 2005-2011, excluding Hassemer and anybody after Voßkuhle
diag(df_05) <- NA                     
M_1 <- as.matrix(df_05)

#Create a hclust dendogram to get a first intuition about whether there can be clusters identified.
#In short, those cluster algorithms try to minimize the variance in groups while keeping the variance between groups
#as large as possible; as a result, members in a group are as similar as possible, while being as different as possible between groups.

g <- graph.adjacency(adjmatrix=M_1, mode="undirected", diag=FALSE, weighted = TRUE) #create an igraph network object
ceb <- fastgreedy.community(g) #Try to find communities in the graph with a cluster algorithm; here, we find two groups
dendPlot(ceb, mode="hclust") #Have a look at the found groups and highlight them visually
plot(ceb, g) #Plot them in a network layout; in the next step, we want to make the graphs visually 
#more appealing by assinging colors according to the parties, use the same font than in the paper etc.

#Create the first communityplot of Figure 1 in the paper
pdf("communityplot_landau1.pdf",
    width = 9,
    height = 9)

#set some seed to make it replicable; please note that different seeds will result in different plot layouts. 
# It can happen that the two communities might overlap, but please note that the two communities 
# stay the same (they are just visually rearranged). For illustrative purposes we use a seed that plots the two communities seperately. 
#Using a different seed will change the layout, but not the main message/finding of the plot. 

set.seed(12345) 
cfg <- cluster_fast_greedy(as.undirected(g))

plot(cfg, as.undirected(g), vertex.size	= 35, 
     col = c("gray42", "gray94", "gray42", "gray42", "gray94", "gray94", "gray42", "gray94"),    
     
     vertex.label = c("Broß", "Osterloh", "Di Fabio", "Mellinghoff", 
                      "Lübbe-Wolff", "Gerhardt", "Landau", "Voßkuhle"),  
     vertex.size = 13,
     vertex.frame.color = "black",
     vertex.label.color = c("gray94", "black", "gray94", "gray94", "black", "black", "gray94", "black"),
     #vertex.label.family = "Arial", #outcomment this line to have the same font like in the paper
     mark.col = c("gray80","gray60"), mark.border=NA,
     mark.shape = .5,
     edge.color = "black"
)

dev.off()

#Create the second part of Figure 1 of the Paper-----------------------------------------
#load data and create matrices for community plot 2011-2015
df_10 <- df[6:13,7:14] #subset original data from 2011-15, from Lübbe-Wolff to Kessal-Wulf
diag(df_10) <- NA                           
M_2 <- as.matrix(df_10)

#Again, get an intuition with an hclust dendogram
g1 <- graph.adjacency(adjmatrix=M_2, mode="undirected", diag=FALSE, weighted = TRUE)
ceb1 <- fastgreedy.community(g1)
dendPlot(ceb1, mode="hclust") ##Ignore the warning message,it simply tells you that there 
#are no clusters in the data!

plot(ceb1, g1) 

#Plot the network by arranging them according to the communities 
#2011-2015 (Second part Figure 1 of the paper)

pdf("communityplot_landau2.pdf", #start graph
    width = 9,
    height = 9)

set.seed(3) #set a seed for the same reasons than before
cfg1 <- cluster_fast_greedy(as.undirected(g1))
plot(cfg1, as.undirected(g1), vertex.size	= 35, 
     col = c("gray94", "gray94", "gray42", "gray94", "gray42", "gray94", "gray42", "gray42"),
     vertex.label = c("Lübbe-Wolff", "Gerhardt", "Landau", "Voßkuhle", "Huber", "Hermanns", "Müller", "Kessal-Wulf"),
     vertex.frame.color = "black",
     vertex.label.color = c("black", "black", "gray94", "black", "gray94", "black", "gray94", "gray94"),
     #vertex.label.family = "Arial", #outcomment this line to have the same font like in the paper
     mark.col = "gray80", mark.border=NA,
     mark.shape = .5,
     edge.color = "black"
)

dev.off() #close graph

##############################################################################################################
#Robustness: make the same graph as in Figure 1 with the reduced matrix----------------------------------------------------------
########################################################################################################
#Note that the matrix stays the same, but the entries in it did change as 
#we only used 9 observations to create them

df1 <- read.csv2("adj_matrix_landau_weighted_reduced.csv", stringsAsFactors = F)
df_05_red <- df1[2:9,3:10] #make a subset from 2005-2011, excluding Hassemer and anybody after Voßkuhle
diag(df_05_red) <- NA                     
M_3 <- as.matrix(df_05_red)

#Create a hclust dendogram to get an intuition about the 
g2 <- graph.adjacency(adjmatrix=M_3, mode="undirected", diag=FALSE, weighted = TRUE)
ceb <- fastgreedy.community(g2)
dendPlot(ceb, mode="hclust") #This time we find again two communities, but they differ: Gerhardt and DiFabio have 
#changed their communities; this is because we have different values for them
plot(ceb, g2)

#Create the first communityplot of Figure 1 in the paper
pdf("communityplot_landau1_reduced.pdf",
    width = 9,
    height = 9)

#set some seed to make it replicable
set.seed(12345678) 

cfg2 <- cluster_fast_greedy(as.undirected(g2))
plot(cfg2, as.undirected(g2), vertex.size	= 35, 
     col = c("gray42", "gray94", "gray42", "gray42", "gray94", "gray94", "gray42", "gray94"),    
     
     vertex.label = c("Broß", "Osterloh", "Di Fabio", "Mellinghoff", 
                      "Lübbe-Wolff", "Gerhardt", "Landau", "Voßkuhle"),  
     vertex.size = 13,
     vertex.frame.color = "black",
     vertex.label.color = c("gray94", "black", "gray94", "gray94", "black", "black", "gray94", "black"),
     #vertex.label.family = "Arial", #outcomment this line to have the same font like in the paper
     mark.col = c("gray80","gray60"), mark.border=NA,
     mark.shape = .5,
     edge.color = "black"
)

dev.off()

#LEAVE THIS OUT IF YOU ARE ALREADY SATISFIED WITH THE PDF FILE; THIS ONE CREATES AN EPS GRAPH
# #save the same graph as an EPS file for an easy import into libre office/ word on Windows/ Linux 
# #machines
# 
# cfg1 <- cluster_fast_greedy(as.undirected(g1))
# setEPS()
# postscript("communityplot_landau2.eps", width = 9,
#            height = 9)
# showtext.begin()
# set.seed(3)
# plot(cfg1, as.undirected(g1), vertex.size	= 35, 
#      col = c("gray94", "gray94", "gray42", "gray94", "gray42", "gray94", "gray42", "gray42"),
#      vertex.label = c("Lübbe-Wolff", "Gerhardt", "Landau", "Voßkuhle", "Huber", "Hermanns", "Müller", "Kessal-Wulf"),
#      vertex.frame.color = "black",
#      vertex.label.color = c("black", "black", "gray94", "black", "gray94", "black", "gray94", "gray94"),
#      #vertex.label.family = "Arial", #outcomment this line to have the same font like in the paper
#      mark.col = "gray80", mark.border=NA,
#      mark.shape = .5,
#      edge.color = "black"
# )
# 
# dev.off()
# 

#load data and create reduced matrices for community plot 2011-2015----------------------------------------
df_10_red <- df1[6:13,7:14] #subset original data from 2011-15, from Lübbe-Wolff to Kessal-Wulf
diag(df_10_red) <- NA   
M_4 <- as.matrix(df_10_red)

#Again, get an intutition with an hclust dendogram
g3 <- graph.adjacency(adjmatrix=M_4, mode="undirected", diag=FALSE, weighted = TRUE)
ceb2 <- cluster_edge_betweenness(g3)
dendPlot(ceb2, mode="hclust") #dendogram of judges: 2 clusters identified
plot(ceb2, g3) 

#again, it doesnt find any communities

pdf("communityplot_landau2_reduced.pdf",
    width = 9,
    height = 9)

cfg3 <- cluster_edge_betweenness(as.undirected(g3))

#Set the seed for replication
set.seed(1234)
plot(cfg3, as.undirected(g3), vertex.size	= 35, 

     col = c("gray94", "gray94", "gray42", "gray94", "gray42", "gray94", "gray42", "gray42"),
     vertex.label = c("Lübbe-Wolff", "Gerhardt", "Landau", "Voßkuhle", "Huber", "Hermanns", "Müller", "Kessal-Wulf"),
     vertex.frame.color = "black",
     vertex.label.color = c("black", "black", "gray94", "black", "gray94", "black", "gray94", "gray94"),
     # vertex.label.family = "Arial", #outcomment this line to have the same font like in the paper
     mark.col = "gray80", mark.border=NA,
     mark.shape = .5,
     edge.color = "black"
)

dev.off()

#Replcation file ends. 

